==> gatsby-remark-codesandbox-1.2.8.tgz: package/index.js <==
'use strict';

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var visit = require('unist-util-visit');
var path = require('path');
var fs = require('fs');

var generateCodeSandboxUrl = require('./get-codesandbox-url');

module.exports = function (_ref) {
  var markdownAST = _ref.markdownAST;

  var _ref2 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      _ref2$classPrefix = _ref2.classPrefix,
      classPrefix = _ref2$classPrefix === undefined ? 'language-' : _ref2$classPrefix;

  visit(markdownAST, 'paragraph', function (paragraph) {
    var validParapgraph = paragraph.children.length === 1 && paragraph.children[0].type === 'link';

    if (!validParapgraph) {
      return;
    }

    var node = paragraph.children[0];

    if (!node.url.startsWith('source:')) {
      return;
    }

    var _node$url$replace$spl = node.url.replace('source:', '').split(/(?={.*})/),
        _node$url$replace$spl2 = _slicedToArray(_node$url$replace$spl, 2),
        sourcePath = _node$url$replace$spl2[0],
        highlights = _node$url$replace$spl2[1];

    var absoluteSourcePath = path.join(process.cwd(), sourcePath);

    if (!fs.existsSync(absoluteSourcePath)) {
      throw new Error('Cannot find source in ' + absoluteSourcePath);
    }

    var sourceCode = fs.readFileSync(absoluteSourcePath).toString().trim();

    var codeSandboxUrl = generateCodeSandboxUrl(sourcePath);

    node.url = codeSandboxUrl;

    paragraph.children.unshift({
      type: 'html',
      value: '<div class="yes"></div>',
      hChildren: [{
        type: 'code',
        lang: path.extname(sourcePath).slice(1) + highlights,
        value: sourceCode
      }]
    });
  });
};

==> gatsby-remark-codesandbox-1.2.11.tgz: package/index.js <==
'use strict';

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var visit = require(`unist-util-visit`);
var path = require('path');
var fs = require('fs');

var generateCodeSandboxUrl = require('./get-codesandbox-url');

module.exports = function (_ref) {
  var markdownAST = _ref.markdownAST;

  var _ref2 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      _ref2$classPrefix = _ref2.classPrefix,
      classPrefix = _ref2$classPrefix === undefined ? `language-` : _ref2$classPrefix;

  visit(markdownAST, `paragraph`, function (paragraph) {
    var validParapgraph = paragraph.children.length === 1 && paragraph.children[0].type === 'link';

    if (!validParapgraph) {
      return;
    }

    var node = paragraph.children[0];

    if (!node.url.startsWith('source:')) {
      return;
    }

    var _node$url$replace$spl = node.url.replace('source:', '').split(/(?={.*})/),
        _node$url$replace$spl2 = _slicedToArray(_node$url$replace$spl, 2),
        sourcePath = _node$url$replace$spl2[0],
        highlights = _node$url$replace$spl2[1];

    var absoluteSourcePath = path.join(process.cwd(), sourcePath);

    if (!fs.existsSync(absoluteSourcePath)) {
      throw new Error(`Cannot find source in ${absoluteSourcePath}`);
    }

    var sourceCode = fs.readFileSync(absoluteSourcePath).toString().trim();

    var codeSandboxUrl = generateCodeSandboxUrl(sourcePath);

    node.url = codeSandboxUrl;

    paragraph.children.unshift({
      type: 'html',
      value: '<div class="yes"></div>',
      hChildren: [{
        type: 'code',
        lang: path.extname(sourcePath).slice(1) + highlights,
        value: sourceCode
      }]
    });
  });
};
